==> recipes_1.0.6.tar.gz: recipes/tests/testthat/_snaps/naomit.md <==
# something prints

    Code
      print(rec)
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:   1
      predictor: 5
      
      -- Operations 
      * Removing rows with NA values in: all_predictors()

---

    Code
      prep(rec)
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:   1
      predictor: 5
      
      -- Training information 
      Training data contained 153 data points and 42 incomplete rows.
      
      -- Operations 
      * Removing rows with NA values in: Solar.R, Wind, Temp, Month, Day | Trained

# empty printing

    Code
      rec
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:    1
      predictor: 10
      
      -- Operations 
      * Removing rows with NA values in: <none>

---

    Code
      rec
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:    1
      predictor: 10
      
      -- Training information 
      Training data contained 32 data points and no incomplete rows.
      
      -- Operations 
      * Removing rows with NA values in: <none> | Trained

==> recipes_1.3.0.tar.gz: recipes/tests/testthat/_snaps/naomit.md <==
# bake method errors when needed non-standard role columns are missing

    Code
      bake(rec_trained, new_data = airquality[, -3])
    Condition
      Error in `step_naomit()`:
      ! The following required column is missing from `new_data`: Wind.

# empty printing

    Code
      rec
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:    1
      predictor: 10
      
      -- Operations 
      * Removing rows with NA values in: <none>

---

    Code
      rec
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:    1
      predictor: 10
      
      -- Training information 
      Training data contained 32 data points and no incomplete rows.
      
      -- Operations 
      * Removing rows with NA values in: <none> | Trained

# printing

    Code
      print(rec)
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:   1
      predictor: 5
      
      -- Operations 
      * Removing rows with NA values in: all_predictors()

---

    Code
      prep(rec)
    Message
      
      -- Recipe ----------------------------------------------------------------------
      
      -- Inputs 
      Number of variables by role
      outcome:   1
      predictor: 5
      
      -- Training information 
      Training data contained 153 data points and 42 incomplete rows.
      
      -- Operations 
      * Removing rows with NA values in: Solar.R, Wind, Temp, Month, Day | Trained
